function [A,F] = assemblestiffload(v,t,pdeg,gi,NDOF)
% Assemble the global stiffness matrix and load vector
% It uses the local stiffness matrix.
% INPUT:
%  v ... Nvert-by-2 coordinates of the vertices (Nvert = number of vertices)
%  t ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
%  pdeg ... Ntri-by-4 vector of polynomial degrees
%           pdeg(k,1) degree of the interior;  pdeg(k,2:4) degrees of the edges
%  gi ... Ntri-by-7  global indices to the stiffness matrix
%     if k is an index of an element then
%     gi(k,1:3) = indices of the three vertices
%     gi(k,4:6) = the first indices of the edge functions
%     gi(k,7)   = the first index of the bubble functions
%  NDOF ... the total number of DOFs (provided by enumerateDOFs.m)
% OUTPUT:
%   A ... the sparse stiffness matrix (NDOF x NDOF)
%   F ... the load vector (NDOF entries)

Ntri = size(t,1);
%Nvert = size(v,1);

% A = spalloc(NDOF,NDOF,nnz);

% Estimate the number of contributions to the global matrix
Nest = 0;
for k=1:Ntri
  % size of the local stiffness matrix
  NK = pdeg(k,2)+pdeg(k,3)+pdeg(k,4) + (pdeg(k,1)-1)*(pdeg(k,1)-2)/2;
  Nest = Nest + NK^2;
end

is = zeros( Nest,1);
js = zeros( Nest,1);
ss = zeros( Nest,1);

F = zeros( NDOF,1);

%blog('---- preparing arrays');
n = 0;
for k = 1 : Ntri

  % compute the local stiffness matrix and the local load vector
  [AK,FK] = locstiffload(k, v,t, pdeg);

  NK = size(AK,1); %pdeg(k,2)+pdeg(k,3)+pdeg(k,4) + (pdeg(k,1)-1)*(pdeg(k,1)-2)/2;

  % prepare auxiliary array of global indices in this element
  giK = locgiarray(k, gi,NK,pdeg(k,1:4));
%    giK = zeros(NK,1);
%    % vertex indices
%    giK(1:3) = gi(k,1:3);  
%    nK = 3;
%    % edge indices
%    for edge=1:3 
%      for i=1:pdeg(k,1+edge)-1
%        nK=nK+1;
%        if (gi(k,3+edge) > 0)  % interior edge
%          giK(nK) = gi(k,3+edge)+i-1;
%        else 
%          giK(nK) = gi(k,3+edge); % boundary edge
%        end
%      end % for i
%    end % for edge
%    % bubble indices
%    for i=1:(pdeg(k,1)-1)*(pdeg(k,1)-2)/2
%      nK=nK+1;
%      giK(nK) = gi(k,7)+i-1;
%    end % for i

  % the assembling loop
  for li = 1 : NK
    idxshf1 = giK(li);
    if (idxshf1 > 0)
      for lj = 1 : NK
        idxshf2 = giK(lj);
        if (idxshf2 > 0)
          n = n + 1;
          is(n) = idxshf1;
          js(n) = idxshf2;
          ss(n) = AK(li,lj);
        % else % the vertex idxV2 is on the Dirichlet boundary
        %   coef_alpha = gD_coef( p(1,t(lj,k)), p(2,t(lj,k)) );
        %   F(idxV1) = F(idxV1) - coef_alpha * LS{k}(li,lj);
        end % if
      end % for lj
      % load vector
      F(idxshf1) = F(idxshf1) + FK(li);
    end % if 
  end % for li
end % for k
%elog();

% !!! estimate NDOF*36 fails for angles smaller then 10 degrees !!!
%nnz = min([NDOF*36, Ntri*6, n]);

%blog('---- creating the sparse matrix');
A = sparse(is(1:n),js(1:n),ss(1:n), NDOF,NDOF, n);
%elog();

end