function pdeg = edgepdeg(neig,polydeg)
% assign polynomial degrees to edges by the minimum rule
% INPUT
%  neig ... Ntri-by-3  element neighbours across edges
%  polydeg ... Ntri-by-1 - polynomial degrees of the elements (interior poly. degrees)
%              This can be a single number. Then each element has this degree.
% OUTPUT
%  pdeg ... Ntri-by-4 vector of polynomial degrees
%           pdeg(k,1) degree of the interior;  pdeg(k,2:4) degrees of the edges

Ntri = size(neig,1);

pdeg = zeros(Ntri,4);

if (length(polydeg) == 1)  % only one polydeg given
  pdeg(1:Ntri,1) = polydeg*ones(Ntri,1);
else                       % a vector of poly. degrees given
  pdeg(1:Ntri,1) = polydeg;
end

for k=1:Ntri
  pb = pdeg(k,1);
  for edge=1:3
    if (neig(k,edge) > 0)
      pe = min([pdeg(neig(k,edge),1), pb]);
    else
      pe = pb;
    end

    % check
    if (pdeg(k,edge+1) ~= 0 && pdeg(k,edge+1) ~= pe)
      error('Mismatch in edge poly. degrees. Wrong neighbours???');
    end

    pdeg(k,edge+1) = pe;

  end % for edge
end % for k
