function val = evaluhploc(xy, k, uhp)
% return the value of uhp at the point xy which have to lie in the triangle k
% INPUT
% xy  ... 2-vector coordinates of a point
% k   ... index (to the array t) of a triangle
% uhp ... the function in the internal format
%   uhp{1} = c  ... NDOF-by-1 the values (DOFs)
%   uhp{2} = gi ... Ntri-by-7  global indices to the stiffness matrix
%   uhp{3} = v  ... Nvert-by-2 coordinates of the vertices (Nvert = number of vertices)
%   uhp{4} = t  ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
%   uhp{5} = pdeg ... Ntri-by-4 vector of polynomial degrees
%                    pdeg(k,1) degree of the interior;  pdeg(k,2:4) degrees of the edges

c  = uhp{1};
gi = uhp{2};
v  = uhp{3};
t  = uhp{4};
pdeg = uhp{5};

%v(t(k,1:3),1:2)  % 3-by-2

W = [v(t(k,1:3),1:2)'; 1 1 1];
lbd = W \ [xy(1); xy(2); 1];  % baricentric coordinates of the point xy

% exponents defining the shape functions
lmn = Peanoshfun(pdeg(k,1:4), t(k,:));  % NK-by-3

% the number of the shapefunctions
NK = pdeg(k,2)+pdeg(k,3)+pdeg(k,4) + (pdeg(k,1)-1)*(pdeg(k,1)-2)/2;  % size of AK

% prepare auxiliary array of global indices in this element
giK = locgiarray(k, gi,NK,pdeg(k,1:4));

val = 0;
for i=1:NK
  idxshf1 = giK(i);
  if (idxshf1 > 0)
    l = lmn(i,1);
    m = lmn(i,2);
    n = lmn(i,3);
    shfval = lbd(1)^l * lbd(2)^m * lbd(3)^n;  % value of the shape function
    val = val + c(idxshf1)*shfval;
  end % if
end % for i

end % function
