function ex2solve
% OUTPUT:
%   The hpFEM solution in uhp in an internal structure.
%   Use evaluhp(uhp,x) to get a value at x
% uhp is a cell array with five element :
% uhp{1} == c     the coefficients
% uhp{2} == gi    the global indices to the stiffness matrix (Ntri-by-7 => 3x vert, 3x edge, 1x inter)
% uhp{3} == v     the vertices of the triangulation
% uhp{4} == t     the triangles of the triangulation
% uhp{5} == pdeg  the polynomial degrees (Ntri-by-4 => interior and three edges)
%
% uhp(x)|_K = \sum_{i=1}^{p(k)+1} c(gi{k}(i))*HPHI{i}(xi),
% uhp(x)|_K =   \sum_{i=1}^3 c(gi(k,i))*lmb_i(x)
%             + \sum_{edge=1}^3 \sum_{i=0}^{pedge-2} c(gi(k,3+edge)+i)*lmb_1(x)^l*lmb_2(x)^m*lmb_3(x)^n
%             + \sum_{i=0}^{Nbub-1} c(gi(k,7)+i)*lmb_1(x)^l*lmb_2(x)^m*lmb_3(x)^n
% where k is the index of element K and
%   l,m,n  are given by Peanoshfun.m
%   lmb    barycentric coordinates

meshfilename='ex2mesh1A.dat';

blog(['Loading mesh "' meshfilename '"']);
load('-mat',meshfilename,'p','e','t');
fprintf('  Ntri=%d  Nboundedge=%d  Nvertices=%d', ...
  size(t,2), size(e,2), size(p,2));
elog();

blog('Precomputing integrals:');
  loadprecompint(); %  precompint;
elog();

v = p(1:2,:)';
t = t(1:3,:)';
polydeg = 2;
uhp = hpFEMsolver(v,t, polydeg);

figure(1);
[rv,rt,ru] = plotuhpdata( uhp, 3 );
plotuhp( v,t, rv,rt,ru, '' );