function n = findneighbours(t)
% Find all neighbours across edges of all triangles in the triangulation.
% INPUT:
%  t ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
% OUTPUT
%  n ... Ntri-by-3 matrix;
%    n[k,i] is a neighbour of triangle k, this neighbour is oposit vertex i,
%    i.e., it is the neighbour across edge i, where edge i is oposit vertex i.
%    i=1,2, or 3;  k=1,2,...,Ntri

Ntri = size(t,1);

n = -1*ones(Ntri,3);

for k = 1 : Ntri-1
  Vk = t(k,1:3);
  for m = k+1 : Ntri
    Wm = t(m,1:3);
    [Vedge,Wedge] = IsNeighbour(Vk,Wm);
    if (Vedge > 0)
      n(k,Vedge) = m;
      n(m,Wedge) = k;
    end % if
  end % for m
end % for k

end % function