function plotuhp( v,t, rv,rt,ru, filename )
% plot the hp-FEM solution
% INPUT
%  v,t ... the original mesh (to be drawn)
%    v ... Nvert-by-2 coordinates of the vertices (Nvert = number of vertices)
%    t ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
%  rv,rt,ru ... the refined mesh (to plot the higher order polynomials) see plotuhpdata.m
%    rv ... 2-by-Nrv  vertices of the refined mesh
%    rt ... 3-by-Nrt  triangles of the refined mesh
%    ru ... Nrv-by-1  vertex data for the refined mesh
% filename ... a string with a file name (with eps ending) to save the figure
%     if filename='' no file is created


clf;
pdesurf(rv,rt, ru);  % ru is a columns => node data
%trimesh( t(1:3,:)', p(1,:)', p(2,:)', -ones(size(p,2),1) );
%pdemesh(p,e,t);

clmin = min(ru);
clmax = max(ru);
%clmin = 0.1*floor(10*clmin);
%clmax = 0.1*ceil(10*clmax);
if (clmin<0)
  fprintf(' Miminum of hp-FEM solution uhp: %g\n', min(ru));
  fprintf(' Maximum of hp-FEM solution uhp: %g\n', max(ru));
end

blacktrimesh(t',v',1.1*clmax);
%blacktrimesh(rt,rv,clmax+0.2);

set(gca,'FontSize',20, 'CLim', [clmin clmax]);
axis square;
%axis([-1 1 -1 1 0 1.4]);
colorbar('FontSize',16);
view(0,90);
shading interp; %flat;
box off;
colormap('default');
%title(['FEM solution ' num2str(astep)]);

if (filename ~= '')
  saveas(gcf,filename,'epsc');
end

end % function
