function [rv,rt,ru] = plotuhpdata( uhp, refinlev )
% plot the hp-FEM solution
% INPUT
% uhp ... the function in the internal format
%   uhp{1} = c  ... NDOF-by-1 the values (DOFs)
%   uhp{2} = gi ... Ntri-by-7  global indices to the stiffness matrix
%   uhp{3} = v  ... Nvert-by-2 coordinates of the vertices (Nvert = number of vertices)
%   uhp{4} = t  ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
%   uhp{5} = pdeg ... Ntri-by-4 vector of polynomial degrees
%                    pdeg(k,1) degree of the interior;  pdeg(k,2:4) degrees of the edges
% refinlev ... refinement level of the mesh for plotting (at each level all edges are halved)
% OUTPUT
% rv ... 2-by-Nrv  vertices of the refined mesh
% rt ... 3-by-Nrt  triangles of the refined mesh
% ru ... Nrv-by-1  vertex data for the refined mesh

c  = uhp{1};
gi = uhp{2};
v  = uhp{3};
t  = uhp{4};
pdeg = uhp{5};

Ntri = size(t,1);

% refine the original triangulation
rt = t;
rvx = v(:,1)';
rvy = v(:,2)';

for rl=1:refinlev
  [rt,rvx,rvy] = unif_ref(rt,rvx,rvy);
end % for rl
rv = [rvx; rvy];  % 2-by-Nrv
rt = rt';  % 3-by-Nrt

Nrv = size(rv,2);

% --- create the vertex data in the new (refined) mesh ---
ru = zeros(Nrv,1);
%  % copy the original vertex data
%  % (the original vertices stay on the same place ==  rv=[v' new_vertices] )
%  for k=1:Ntri
%    for iv=1:3
%      if (gi(k,iv) > 0)
%        ru(t(k,iv)) = c(gi(k,iv));
%      else
%        ru(t(k,iv)) = 0;  % Dirichlet boundary
%      end % if
%    end % for iv
%  end % for k

% the first Nsubtri triangles in rt are sons of t(1,:)
% the secon Nsubtri triangles in rt are sons of t(2,:)
% etc.
Nsubtri = 4^refinlev;

% fill all the vertex data in the new mesh by values from uhp
for k=1:Ntri  % k == index of the triangle in the rough mesh
  for kloc=1:Nsubtri
    rk = (k-1)*Nsubtri + kloc;  % rk == index of the triangle in the refined mesh
    for iv=1:3  % three vertices of the refined triangle
      rx = rv(1:2,rt(iv,rk)); % coordinates of the vertex
      val = evaluhploc(rx, k, uhp); % evaluate uhp(rx(1),rx(2));  rx is in the big triangle k
      %uval = exactsol(rx(1),rx(2));
      ru( rt(iv,rk) ) = val;
    end % for iv
  end % for kloc
end % for k


% pdesurf(rv,rt, ru);

end % function
